@@ -83,7 +83,8 @@ atspi_get_desktop (gint i)
  * this implementation always returns a #Garray with a single
  * #AtspiAccessible desktop.
  *
- * Returns: (transfer full): a #GArray of desktops.
+ * Returns: (element-type AtspiAccessible*) (transfer full): a #GArray of
+ * desktops.
  **/
 GArray *
 atspi_get_desktop_list ()
@@ -197,7 +198,8 @@ atspi_register_keystroke_listener (AtspiDeviceListener  *listener,
 					 GArray             *key_set,
 					 AtspiKeyMaskType         modmask,
 					 AtspiKeyEventMask        event_types,
-					 gint sync_type, GError **error)
+					 AtspiKeyListenerSyncType sync_type,
+                                         GError **error)
 {
   DeviceListenerEntry *e;
 
@@ -347,7 +349,7 @@ atspi_deregister_keystroke_listener (AtspiDeviceListener *listener,
  *             the events.
  * @event_types: an #AtspiDeviceEventMask mask indicating which
  *             types of key events are requested (%ATSPI_KEY_PRESSED, etc.).
- * @filter: Unused parameter.
+ * @filter: (allow-none): Unused parameter.
  * @error: (allow-none): a pointer to a %NULL #GError pointer, or %NULL
  *             
  * Registers a listener for device events, for instance button events.
@@ -385,7 +387,7 @@ atspi_register_device_event_listener (AtspiDeviceListener  *listener,
  * atspi_deregister_device_event_listener:
  * @listener: a pointer to the #AtspiDeviceListener for which
  *            device events are requested.
- * @filter: Unused parameter.
+ * @filter: (allow-none): Unused parameter.
  * @error: (allow-none): a pointer to a %NULL #GError pointer, or %NULL
  *
  * Removes a device event listener from the registry's listener queue,
